# Enterprise network, 11 nodes

set ns [new Simulator]
source tb_compat.tcl

proc tarfile-append {node tdir tfile} {
    set name "$tdir /proj/SHN/tarfiles/$tfile"
    set orig [$node set tarfiles]
    if {$orig == {}} {
       $node set tarfiles $name
    } else {
       $node set tarfiles [join [list $orig $name]  ";"]
    }
}

set proggroup [$ns event-group]

set manager [$ns node]
tb-set-hardware manager bpc2800
set manager-prog [manager program-agent]
$proggroup add manager-prog
tb-set-node-os manager SHN_Base

foreach node {n1 n2 n3 n4 n5} {
   set $node [$ns node]
   tb-set-hardware $node bpc2800

   set $node-prog [$node program-agent]
   $proggroup add $node-prog

   tb-set-node-os $node SHN_Base
   tarfile-append $node / harpoon.tar.gz
   tarfile-append $node / floodwatch.tar.gz
   tarfile-append $node / cossack.tar.gz
   tarfile-append $node / dward.tar.gz
   tarfile-append $node / cleo.tar.gz

   tarfile-append $node /usr pircd.tar.gz

   tarfile-append $node /usr/bin fc4.D.tar.gz
   tarfile-append $node /var/www/html web.D.tar.gz
}

tarfile-append n3 /usr/local/etc/emulab ntpstart.tar.gz
tarfile-append n3 /etc ntpconf.tar.gz

foreach node {buildingSwitch br0} {
   set $node [$ns node]
   tb-set-hardware $node bpc2800

   set $node-prog [$node program-agent]
   $proggroup add $node-prog

   tb-set-node-os $node FC4-SMP8-2
   tarfile-append $node / harpoon.tar.gz
   tarfile-append $node / floodwatch.tar.gz
   tarfile-append $node / cossack.tar.gz
   tarfile-append $node / dward.tar.gz
   tarfile-append $node / cleo.tar.gz

   tarfile-append $node /usr pircd.tar.gz

   tarfile-append $node /usr/bin fc4.D.tar.gz
   tarfile-append $node /var/www/html web.D.tar.gz

}

# Create the client PCs
foreach node {pr1 s1 e1} {

   set $node [$ns node]
   tb-set-hardware $node bpc2800

   tb-set-node-os $node SHN_Base
   set $node-prog [$node program-agent]
   $proggroup add $node-prog

   tarfile-append $node / harpoon.tar.gz
   tarfile-append $node / floodwatch.tar.gz
   tarfile-append $node / cossack.tar.gz
   tarfile-append $node / dward.tar.gz
   tarfile-append $node / cleo.tar.gz

   tarfile-append $node /usr pircd.tar.gz

   tarfile-append $node /usr/bin fc4.D.tar.gz
   tarfile-append $node /var/www/html web.D.tar.gz

}


set link0 [$ns duplex-link $br0 $buildingSwitch 1000Mb 0ms DropTail]

set floor0 [$ns make-lan "$pr1 $n1 $buildingSwitch" 1000Mb 0ms]
set floor1 [$ns make-lan "$s1 $manager $buildingSwitch" 1000Mb 0ms]
set floor2 [$ns make-lan "$e1 $n2 $buildingSwitch" 1000Mb 0ms]
set DataCenter0 [$ns make-lan "$n3 $n4 $n5 $br0" 1000Mb 0ms]


foreach node {pr1 n2} {
  tb-set-node-lan-params $node $floor0 0ms 100Mb 0.0
}

foreach node {s1 manager} {
  tb-set-node-lan-params $node $floor1 0ms 100Mb 0.0
}

foreach node {e1} {
  tb-set-node-lan-params $node $floor2 0ms 100Mb 0.0
}

set setupseq [$ns event-sequence {
    $proggroup run -command "sudo experiment-setup.pl D >& /tmp/exp.log"
}]

$ns at 0 "$setupseq start"
$ns rtproto Static
$ns run
